@@ -6,7 +6,8 @@ __all__=['calc_phase',
         'poly_frequency',
         'sin_frequency',
         'sin_quart_frequency',
-        'sin_half_frequency'
+        'sin_half_frequency',
+        'sin_phase_frequency'
         ]
 
 #-------------------------------
@@ -218,6 +219,7 @@ def sin_quart_frequency(f0, delta_f, length, fs):
     t = np.arange(length)/fs
     tm = length/fs
     return (f0)+delta_f*np.sin((2*np.pi*t/tm)/4)
+
 #-------------------------------
 def sin_half_frequency(f0, delta_f, length, fs):
     '''
@@ -244,3 +246,32 @@ def sin_half_frequency(f0, delta_f, length, fs):
     t = np.arange(length)/fs
     tm = length/fs
     return (f0)+delta_f*np.sin((2*np.pi*t/tm)/2)
+
+#-------------------------------
+def sin_phase_frequency(f0, delta_f, length, fs, phi0=0, phiN=np.pi/4):
+    '''
+    Arbitarry sinus frequency to time relation.
+      ..math::      
+      f(n) = f0+delta_f*sin(2pi*n/(Tm*fs*pi/phiN)+phi0),
+      Tm = N/fs, n=0,...,N-1
+
+    Paramteres
+    ------------
+    f0: float,
+      carried frequency.
+    delta_f: float,
+      frequency bandwidth.
+    length: int,
+      length of relation.
+    fs: float,
+      sampling frequency.
+    
+    Return
+    ----------
+    freq: 1d ndarray.
+    '''
+    t = np.arange(length)/fs
+    tm = length/fs
+    divider = np.pi/phiN
+    freqm = np.sin(2*np.pi*t/(tm*divider)+phi0)
+    return (f0)+delta_f*(freqm-min(freqm))/(max(freqm)-min(freqm))
