@@ -35,5 +35,5 @@ from ._geometry import (calc_line,
                         point_to_vector_distance)
 
 
-from ._smooth import movingaverage, movav
+from ._smooth import moving_average, movav
 from ..operators import *
